@@ -1,11 +1,11 @@
-hydrology.soilInfiltration<-function(input, Ssoil){
+hydrology_infiltrationAmount<-function(input, Ssoil){
   I = rep(0, length(input))
   sel = input>(0.2*Ssoil)
   I[sel] = input[sel]-((input[sel]-0.2*Ssoil)^2/(input[sel]+0.8*Ssoil))
   I[!sel] = input[!sel]
   return(I)
 }
-hydrology.rainInterception<-function(Rainfall, Cm, p, ER=0.05, method="Gash1995"){
+hydrology_rainInterception<-function(Rainfall, Cm, p, ER=0.05, method="Gash1995"){
   METHODS <- c("Liu2001","Gash1995")
   method <- match.arg(method, METHODS)
   if(length(ER)==1) ER =rep(ER, length(Rainfall))
