@@ -167,12 +167,13 @@ NumericVector soilWaterInputs(List soil, String soilFunctions, double prec, doub
 // [[Rcpp::export("hydrology_soilInfiltrationPercolation")]]
 NumericVector soilInfiltrationPercolation(List soil, String soilFunctions, 
                                           double waterInput,
-                                          bool drainage = true, bool modifySoil = true) {
+                                          bool rockyLayerDrainage = true, bool modifySoil = true) {
   //Soil input
   NumericVector W = clone(Rcpp::as<Rcpp::NumericVector>(soil["W"])); //Access to soil state variable
   NumericVector dVec = soil["dVec"];
   NumericVector macro = soil["macro"];
   NumericVector rfc = soil["rfc"];
+  double Kdrain = soil["Kdrain"];
   NumericVector Water_FC = waterFC(soil, soilFunctions);
   NumericVector Water_SAT = waterSAT(soil, soilFunctions);
   int nlayers = W.size();
@@ -188,32 +189,62 @@ NumericVector soilInfiltrationPercolation(List soil, String soilFunctions,
     //Decide infiltration repartition among layers
     NumericVector Ivec = infiltrationRepartition(Infiltration, dVec, macro);
     //Input of the first soil layer is infiltration
-    double excess = 0.0;
+    double percolationExcess = 0.0;
     double Wn;
-    //Update topsoil layer
     for(int l=0;l<nlayers;l++) {
       if((dVec[l]>0.0) & (Ivec[l]>0.0)) {
         Wn = W[l]*Water_FC[l] + Ivec[l]; //Update water volume
         if(l<(nlayers-1)) {
           Ivec[l+1] = Ivec[l+1] + std::max(Wn - Water_FC[l],0.0); //update Ivec adding the excess to the infiltrating water (saturated flow)
+          W[l] = std::max(0.0,std::min(Wn, Water_FC[l])/Water_FC[l]); //Update theta (this modifies 'soil')
         } else {
-          excess = std::max(Wn - Water_FC[l],0.0); //Set excess of the bottom layer
+          if((rfc[l]<95.0) | rockyLayerDrainage) { //If not a rock layer or rocky layer drainage is allowed
+            W[l] = std::max(0.0,std::min(Wn, Water_FC[l])/Water_FC[l]); //Update theta (this modifies 'soil')
+            percolationExcess = std::max(Wn - Water_FC[l],0.0); //Set excess of the bottom layer using field capacity
+          } else {
+            W[l] = std::max(0.0,std::min(Wn, Water_SAT[l])/Water_FC[l]); //Update theta (this modifies 'soil')
+            percolationExcess = std::max(Wn - Water_SAT[l],0.0); //Set excess of the bottom layer using saturation
+          }
         }
-        W[l] = std::max(0.0,std::min(Wn, Water_FC[l])/Water_FC[l]); //Update theta (this modifies 'soil')
       } 
-    }
-    if(drainage) {//Set deep drainage
-      DeepDrainage = excess; 
-    } else { //Fill to saturation and upwards if needed
+    } 
+    //If there still excess fill layers over field capacity
+    if(percolationExcess>0.0) {
       for(int l=(nlayers-1);l>=0;l--) {
-        if((dVec[l]>0.0) & (excess>0.0)) {
-          Wn = W[l]*Water_FC[l] + excess; //Update water volume
-          excess = std::max(Wn - Water_SAT[l],0.0); //Update excess, using the excess of water over saturation
+        if((dVec[l]>0.0) & (percolationExcess>0.0)) {
+          Wn = W[l]*Water_FC[l] + percolationExcess; //Update water volume
+          percolationExcess = std::max(Wn - Water_SAT[l],0.0); //Update excess, using the excess of water over saturation
           W[l] = std::max(0.0,std::min(Wn, Water_SAT[l])/Water_FC[l]); //Update theta (this modifies 'soil') here no upper
         }
       }
-      if(excess>0.0) { //If soil is completely saturated increase Runoff
-        Runoff = Runoff + excess;
+      //If soil is completely saturated increase surface Runoff
+      if(percolationExcess>0.0) { 
+        Runoff = Runoff + percolationExcess;
+      }
+    }
+  }
+  //If there is still room for additional drainage (water in macropores accumulated from previous days)
+  double head = 0.0;
+  for(int l=0;l<nlayers;l++) { //Add mm over field capacity
+    if((l<(nlayers-1)) | (rfc[l] < 95.0) | rockyLayerDrainage) {
+      head += Water_FC[l]*std::max(W[l] - 1.0, 0.0);
+    }
+  }
+  if(head>0.0) {
+    double maxDrainage = head*Kdrain;
+    for(int l=0;l<nlayers;l++) {
+      if(maxDrainage>0.0) {
+        double Wn = W[l]*Water_FC[l];
+        double toDrain = std::min(std::max(Wn - Water_FC[l], 0.0), maxDrainage);
+        if((l==(nlayers-1)) & (rfc[l] >= 95.0) & (!rockyLayerDrainage)) { //Prevent drainage for last rocky layer if not allowed
+          toDrain = 0.0;
+        }
+        if(toDrain > 0.0) {
+          DeepDrainage +=toDrain;
+          maxDrainage -=toDrain;
+          Wn -= toDrain;
+          W[l] = std::max(0.0, Wn/Water_FC[l]); //Update theta (this modifies 'soil') here no upper          
+        }
       }
     }
   }
