@@ -154,11 +154,10 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
   double costModifier = control["costModifier"];
   double gainModifier = control["gainModifier"];
   bool plantWaterPools = control["plantWaterPools"];
-  double poolOverlapFactor = control["poolOverlapFactor"];
   double verticalLayerSize = control["verticalLayerSize"];
   double thermalCapacityLAI = control["thermalCapacityLAI"];
   double defaultWindSpeed = control["defaultWindSpeed"];
-  double nonSugarConc = control["nonSugarConc"];
+  double nonSugarConcentration = control["nonSugarConcentration"];
   
   //Vegetation input
   DataFrame cohorts = Rcpp::as<Rcpp::DataFrame>(x["cohorts"]);
@@ -190,17 +189,21 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
   List canopyParams = Rcpp::as<Rcpp::List>(x["canopy"]);
   
   //Root distribution input
-  List below = Rcpp::as<Rcpp::List>(x["below"]);
-  NumericMatrix V =Rcpp::as<Rcpp::NumericMatrix>(below["V"]);
-  NumericMatrix VCroot_kmax= Rcpp::as<Rcpp::NumericMatrix>(below["VCroot_kmax"]);
-  NumericMatrix VGrhizo_kmax= Rcpp::as<Rcpp::NumericMatrix>(below["VGrhizo_kmax"]);
+  DataFrame belowdf = Rcpp::as<Rcpp::DataFrame>(x["below"]);
+  List belowLayers = Rcpp::as<Rcpp::List>(x["belowLayers"]);
+  NumericMatrix V =Rcpp::as<Rcpp::NumericMatrix>(belowLayers["V"]);
+  NumericMatrix VCroot_kmax= Rcpp::as<Rcpp::NumericMatrix>(belowLayers["VCroot_kmax"]);
+  NumericMatrix VGrhizo_kmax= Rcpp::as<Rcpp::NumericMatrix>(belowLayers["VGrhizo_kmax"]);
   
   //Water pools
-  NumericMatrix Wpool = Rcpp::as<Rcpp::NumericMatrix>(below["Wpool"]);
+  NumericMatrix Wpool = Rcpp::as<Rcpp::NumericMatrix>(belowLayers["Wpool"]);
   NumericMatrix Wrhizo;
   List RHOP;
   NumericVector poolProportions(numCohorts);
-  
+  if(plantWaterPools) {
+    RHOP = belowLayers["RHOP"];
+    poolProportions = belowdf["poolProportions"];
+  }
   
   //Base parameters
   DataFrame paramsInterception = Rcpp::as<Rcpp::DataFrame>(x["paramsInterception"]);
@@ -251,7 +254,7 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
   NumericVector Stem1PsiVEC = Rcpp::as<Rcpp::NumericVector>(internalWater["Stem1Psi"]);
   NumericVector Stem2PsiVEC = Rcpp::as<Rcpp::NumericVector>(internalWater["Stem2Psi"]);
   NumericVector RootCrownPsiVEC = Rcpp::as<Rcpp::NumericVector>(internalWater["RootCrownPsi"]);
-  NumericMatrix RhizoPsiMAT = Rcpp::as<Rcpp::NumericMatrix>(below["RhizoPsi"]);
+  NumericMatrix RhizoPsiMAT = Rcpp::as<Rcpp::NumericMatrix>(belowLayers["RhizoPsi"]);
   NumericVector EinstVEC = Rcpp::as<Rcpp::NumericVector>(internalWater["Einst"]);
   NumericVector NSPLVEC = Rcpp::as<Rcpp::NumericVector>(internalWater["NSPL"]);
   
@@ -418,10 +421,6 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
   //Hydraulics: supply functions
   List soil_c;
   if(plantWaterPools) {
-    //Calculate proportions of cohort-unique pools
-    for(int c=0;c<numCohorts;c++) poolProportions[c] = LAIlive[c]/LAIcelllive;
-    //Calculate proportions of rhizosphere overlapping other pools
-    RHOP = horizontalProportions(V, LAIlive, poolOverlapFactor);
     soil_c= clone(soil); //Clone soil
     //Calculate average rhizosphere moisture, including rhizosphere overlaps
     Wrhizo = cohortRhizosphereMoisture(Wpool, RHOP);
@@ -488,8 +487,8 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
   NumericVector sugarLeaf(numCohorts, 0.0);
   NumericVector sugarSapwood(numCohorts, 0.0);
   for(int c=0;c<numCohorts;c++) {
-    sugarLeaf[c] = sugarConcentration(LeafPI0[c],20.0, nonSugarConc);
-    sugarSapwood[c] = sugarConcentration(StemPI0[c],20.0, nonSugarConc);
+    sugarLeaf[c] = sugarConcentration(LeafPI0[c],20.0, nonSugarConcentration);
+    sugarSapwood[c] = sugarConcentration(StemPI0[c],20.0, nonSugarConcentration);
   }
   
   //Transpiration and photosynthesis
@@ -570,8 +569,8 @@ List transpirationSperry(List x, List soil, double tmin, double tmax,
     
     for(int c=0;c<numCohorts;c++) { //Plant cohort loop
       //Current osmotic potentials
-      double leafpi0 = osmoticWaterPotential(sugarLeaf[c], Tcan[n], nonSugarConc);
-      double stempi0 = osmoticWaterPotential(sugarSapwood[c], Tcan[n], nonSugarConc);
+      double leafpi0 = osmoticWaterPotential(sugarLeaf[c], Tcan[n], nonSugarConcentration);
+      double stempi0 = osmoticWaterPotential(sugarSapwood[c], Tcan[n], nonSugarConcentration);
       
       
       //default values
@@ -1305,8 +1304,7 @@ List transpirationGranier(List x, List soil, double tday, double pet,
   String soilFunctions = control["soilFunctions"];
   double verticalLayerSize = control["verticalLayerSize"];
   bool plantWaterPools = control["plantWaterPools"];
-  double poolOverlapFactor = control["poolOverlapFactor"];
-  
+
   //Soil water at field capacity
   NumericVector Water_FC = waterFC(soil, soilFunctions);
   
@@ -1321,15 +1319,19 @@ List transpirationGranier(List x, List soil, double tday, double pet,
   int numCohorts = LAIphe.size();
 
   //Root distribution input
-  List below = Rcpp::as<Rcpp::List>(x["below"]);
-  NumericMatrix V = Rcpp::as<Rcpp::NumericMatrix>(below["V"]);
+  DataFrame belowdf = Rcpp::as<Rcpp::DataFrame>(x["below"]);
+  List belowLayers = Rcpp::as<Rcpp::List>(x["belowLayers"]);
+  NumericMatrix V = Rcpp::as<Rcpp::NumericMatrix>(belowLayers["V"]);
 
   //Water pools
-  NumericMatrix Wpool = Rcpp::as<Rcpp::NumericMatrix>(below["Wpool"]);
+  NumericMatrix Wpool = Rcpp::as<Rcpp::NumericMatrix>(belowLayers["Wpool"]);
   NumericMatrix Wrhizo;
   List RHOP;
   NumericVector poolProportions(numCohorts);
-  
+  if(plantWaterPools) {
+    RHOP = belowLayers["RHOP"];
+    poolProportions = belowdf["poolProportions"];
+  }
   //Parameters  
   DataFrame paramsInterception = Rcpp::as<Rcpp::DataFrame>(x["paramsInterception"]);
   NumericVector kPAR = Rcpp::as<Rcpp::NumericVector>(paramsInterception["kPAR"]);
@@ -1385,10 +1387,6 @@ List transpirationGranier(List x, List soil, double tday, double pet,
   NumericVector psiSoil = psi(soil,soilFunctions); //Update soil water potential
   List soil_c;
   if(plantWaterPools) {
-    //Calculate proportions of cohort-unique pools
-    for(int c=0;c<numCohorts;c++) poolProportions[c] = LAIlive[c]/LAIcelllive;
-    //Calculate proportions of rhizosphere overlapping other pools
-    RHOP = horizontalProportions(V, LAIlive, poolOverlapFactor);
     soil_c= clone(soil); //Clone soil
     //Calculate average rhizosphere moisture, including rhizosphere overlaps
     Wrhizo = cohortRhizosphereMoisture(Wpool, RHOP);
@@ -1450,7 +1448,6 @@ List transpirationGranier(List x, List soil, double tday, double pet,
     NumericVector Ws = soil["W"];
     for(int l=0;l<nlayers;l++) Ws[l] = Ws[l] - (sum(EplantCoh(_,l))/Water_FC[l]); 
     if(plantWaterPools) {
-      
       rhizosphereMoistureExtraction(EplantCoh, Water_FC,
                                     Wpool, RHOP,
                                     poolProportions);
